@@ -6,6 +6,7 @@ import re
 from datetime import (
     date,
     datetime,
+    timedelta,
 )
 from decimal import (
     Decimal,
@@ -247,6 +248,180 @@ def parse_date(input_value: str, date_format: str | None = None, error_message:
         return Maybe.failure(error_message or 'Input must be a valid date')
 
 
+def parse_datetime(input_value: str | None, error_message: str | None = None) -> Maybe[datetime]:
+    """Parse a string to a timezone-aware datetime object.
+
+    Parses datetime strings in ISO 8601 format with timezone information.
+    Requires timezone to be specified (naive datetimes are rejected).
+
+    Supports:
+    - Z suffix for UTC (e.g., '2024-01-01T12:00:00Z')
+    - Explicit UTC offset (e.g., '2024-01-01T12:00:00+00:00')
+    - Positive/negative timezone offsets (e.g., '2024-01-01T12:00:00+05:30', '2024-01-01T12:00:00-08:00')
+    - Fractional seconds (e.g., '2024-01-01T12:00:00.123456Z')
+
+    Args:
+        input_value: String to parse (leading/trailing whitespace is stripped)
+        error_message: Optional custom error message for parsing failures
+
+    Returns:
+        Maybe[datetime]: Success(datetime) if parsing succeeds with timezone info,
+                        Failure(str) with error message otherwise
+
+    Examples:
+        >>> parse_datetime("2024-01-01T12:00:00Z")
+        Success(datetime.datetime(2024, 1, 1, 12, 0, tzinfo=datetime.timezone.utc))
+        >>> parse_datetime("2024-01-01T12:00:00+05:30")
+        Success(datetime.datetime(2024, 1, 1, 12, 0, tzinfo=datetime.timezone(datetime.timedelta(seconds=19800))))
+        >>> parse_datetime("2024-01-01T12:00:00").is_failure()
+        True
+    """
+    # Handle None or non-string input
+    if input_value is None or not isinstance(input_value, str):
+        return Maybe.failure(error_message or 'Input must not be empty')
+
+    # Strip whitespace
+    s = input_value.strip()
+    if s == '':
+        return Maybe.failure(error_message or 'Input must not be empty')
+
+    # DoS protection: Early length guard (reasonable max for ISO datetime)
+    # ISO 8601 datetime with timezone: ~35 chars max including microseconds
+    if len(input_value) > 100:
+        return Maybe.failure(error_message or 'Input is too long')
+
+    try:
+        # Parse ISO 8601 datetime with timezone
+        # Note: fromisoformat in Python < 3.11 doesn't accept 'Z' suffix
+        dt = datetime.fromisoformat(s.replace('Z', '+00:00'))  # noqa: FURB162
+
+        # Require timezone-aware datetime
+        if dt.tzinfo is None:
+            return Maybe.failure(error_message or 'Datetime must include timezone information')
+
+        return Maybe.success(dt)
+    except ValueError:
+        return Maybe.failure(error_message or 'Input must be a valid ISO 8601 datetime')
+
+
+def parse_timedelta(input_value: str | None, error_message: str | None = None) -> Maybe[timedelta]:
+    """Parse a string to a timedelta object.
+
+    Parses duration strings in multiple formats:
+    - Simple format: '90m', '2h', '45s', '3d'
+    - Combined format: '1h 30m', '1d 2h 30m 45s', '1h30m' (no spaces)
+    - ISO 8601 duration: 'PT1H30M', 'P1DT2H', 'PT45S'
+
+    Supported units:
+    - d: days
+    - h: hours
+    - m: minutes
+    - s: seconds
+
+    Args:
+        input_value: String to parse (leading/trailing whitespace is stripped)
+        error_message: Optional custom error message for parsing failures
+
+    Returns:
+        Maybe[timedelta]: Success(timedelta) if parsing succeeds,
+                         Failure(str) with error message otherwise
+
+    Examples:
+        >>> parse_timedelta("90m")
+        Success(datetime.timedelta(seconds=5400))
+        >>> parse_timedelta("1h 30m")
+        Success(datetime.timedelta(seconds=5400))
+        >>> parse_timedelta("PT1H30M")
+        Success(datetime.timedelta(seconds=5400))
+        >>> parse_timedelta("-90m").is_failure()
+        True
+    """
+    # Handle None or non-string input
+    if input_value is None or not isinstance(input_value, str):
+        return Maybe.failure(error_message or 'Input must not be empty')
+
+    # Strip whitespace
+    s = input_value.strip()
+    if s == '':
+        return Maybe.failure(error_message or 'Input must not be empty')
+
+    # DoS protection: Early length guard (reasonable max for duration string)
+    if len(input_value) > 200:
+        return Maybe.failure(error_message or 'Input is too long')
+
+    try:
+        # Check for negative values early
+        if s.startswith('-'):
+            return Maybe.failure(error_message or 'Duration cannot be negative')
+
+        # Try ISO 8601 duration format first (e.g., PT1H30M, P1DT2H)
+        if s.startswith('P'):
+            return _parse_iso_duration(s, error_message)
+
+        # Try simple/combined format (e.g., '90m', '1h 30m', '1h30m')
+        return _parse_simple_duration(s, error_message)
+
+    except (ValueError, AttributeError):
+        return Maybe.failure(error_message or 'Input must be a valid duration')
+
+
+def _parse_iso_duration(s: str, error_message: str | None) -> Maybe[timedelta]:
+    """Parse ISO 8601 duration format (internal helper).
+
+    Pattern format: P[nD][T[nH][nM][nS]]
+    Examples: PT1H30M, P1DT2H, PT45S, P1D
+    """
+    pattern = r'^P(?:(\d+)D)?(?:T(?:(\d+)H)?(?:(\d+)M)?(?:(\d+(?:\.\d+)?)S)?)?$'
+    match = re.match(pattern, s, re.IGNORECASE)
+
+    if not match:
+        return Maybe.failure(error_message or 'Input must be a valid duration')
+
+    days_str, hours_str, minutes_str, seconds_str = match.groups()
+
+    days = int(days_str) if days_str else 0
+    hours = int(hours_str) if hours_str else 0
+    minutes = int(minutes_str) if minutes_str else 0
+    seconds = float(seconds_str) if seconds_str else 0.0
+
+    td = timedelta(days=days, hours=hours, minutes=minutes, seconds=seconds)
+    return Maybe.success(td)
+
+
+def _parse_simple_duration(s: str, error_message: str | None) -> Maybe[timedelta]:
+    """Parse simple/combined duration format (internal helper).
+
+    Matches sequences like '1d', '2h', '30m', '45s'.
+    Supports both '1h 30m' (with spaces) and '1h30m' (without spaces).
+    """
+    pattern = r'(\d+)\s*([dhms])'
+    matches = re.findall(pattern, s, re.IGNORECASE)
+
+    if not matches:
+        return Maybe.failure(error_message or 'Input must be a valid duration')
+
+    days = 0
+    hours = 0
+    minutes = 0
+    seconds = 0
+
+    for value_str, unit in matches:
+        value = int(value_str)
+        unit_lower = unit.lower()
+
+        if unit_lower == 'd':
+            days += value
+        elif unit_lower == 'h':
+            hours += value
+        elif unit_lower == 'm':
+            minutes += value
+        elif unit_lower == 's':
+            seconds += value
+
+    td = timedelta(days=days, hours=hours, minutes=minutes, seconds=seconds)
+    return Maybe.success(td)
+
+
 def parse_complex(input_value: str, error_message: str | None = None) -> Maybe[complex]:
     """Parse a string to a complex number.
 
@@ -2021,6 +2196,7 @@ def parse_path(
     *,
     expand_user: bool = False,
     resolve: bool = False,
+    error_message: str | None = None,
 ) -> Maybe[Path]:
     """Parse a string into a pathlib.Path object.
 
@@ -2032,6 +2208,7 @@ def parse_path(
         text: The path string to parse (leading/trailing whitespace is stripped)
         expand_user: If True, expand ~ to user's home directory (default: False)
         resolve: If True, resolve to absolute path following symlinks (default: False)
+        error_message: Custom error message for invalid input (optional)
 
     Returns:
         Maybe[Path]: Success(Path) if parsing succeeds, Failure(str) with error message otherwise
@@ -2052,14 +2229,21 @@ def parse_path(
         - Use expand_user=True to expand ~ to the user's home directory
         - Use resolve=True to convert relative paths to absolute paths
         - The resolve option will follow symlinks and normalize the path
+        - Input length is limited to 4096 characters to prevent DoS attacks
     """
     # Handle None or empty input
     if text is None or not isinstance(text, str):
-        return Maybe.failure('Path cannot be empty')
+        return Maybe.failure(error_message or 'Path cannot be empty')
 
     stripped = text.strip()
     if stripped == '':
-        return Maybe.failure('Path cannot be empty')
+        return Maybe.failure(error_message or 'Path cannot be empty')
+
+    # CRITICAL: Early length guard (DoS mitigation)
+    # Reject oversized inputs BEFORE expensive Path operations
+    # Most filesystems have path length limits around 4096 bytes (PATH_MAX)
+    if len(text) > 4096:
+        return Maybe.failure(error_message or 'Invalid format: path is too long')
 
     try:
         # Create Path object (automatically normalizes redundant separators)
@@ -2075,7 +2259,7 @@ def parse_path(
 
         return Maybe.success(path)
     except (ValueError, OSError) as e:
-        return Maybe.failure(f'Invalid path: {e!s}')
+        return Maybe.failure(error_message or f'Invalid path: {e!s}')
 
 
 # Public API exports
@@ -2090,6 +2274,7 @@ __all__ = [
     'parse_cidr',
     'parse_complex',
     'parse_date',
+    'parse_datetime',
     'parse_decimal',
     'parse_dict',
     'parse_dict_with_validation',
@@ -2109,6 +2294,7 @@ __all__ = [
     'parse_phone',
     'parse_set',
     'parse_slug',
+    'parse_timedelta',
     'parse_url',
     'parse_uuid',
     'validated_parser',
